# coding: utf-8

"""
    Red Rover API

    Access Red Rover data via this REST API for Organizations that have granted you access.    # Authentication  The API is protected by HTTP Basic Authentication.   Each application that connects to the API has a unique username and password that it must supply with every request.    This value needs to be supplied as an HTTP Header: `Authorization=BASIC [hash]`. The value of [hash] is the string username:password base64 encoded.    Endpoints marked for Basic Auth can be used with the Basic Auth username and password that you have been assigned.    # API Information  ## Api Key  Each Red Rover organization that has authorized your application has a unique API Key for your application.  To retrieve the API Key, you can use the Organization endpoint (`api/v1/organization`) which returns an ApiKey uniquely used for each Organization.    You must supply this as an HTTP Header when accessing that organization: `apiKey=[apiKey]`. The domains that require this `ApiKey` header are labeled as 'Requires an ApiKey'.    ## Identifier  Where an `Identifier` can be specified in the route, you may either supply the Red Rover Id of the object (numeric) or the External Id (alpha-numeric). When specifying an External Id, you will need to prepend the External Id with the pike character`|` (e.g. `|ABC123`). Please note that this is only the case when the External Id is within the route. If the External Id is contained within the body of the request, do not append the pike character.    ## Transaction Id  Each request can be supplied with a `TransactionId` GUID which will be logged with the request. The `Transaction Id` can be supplied as an HTTP Header: `TransactionId=[transactionId]`. If no `Transaction Id` is supplied, one will be generated for you. Please use a distinct TransactionId for each request.

    The version of the OpenAPI document: v1
    Contact: dev@redroverk12.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, conlist
from redrover_api.models.absence_detail_response import AbsenceDetailResponse
from redrover_api.models.org_user_employee_response import OrgUserEmployeeResponse
from redrover_api.models.vacancy_response import VacancyResponse

class AbsenceResponse(BaseModel):
    """
    Absence  # noqa: E501
    """
    id: Optional[StrictInt] = Field(None, description="The Red Rover internal Id of Absence (numeric)")
    external_id: Optional[StrictStr] = Field(None, alias="externalId", description="The external Id of Absence (alpha-numeric)")
    org_id: Optional[StrictInt] = Field(None, alias="orgId", description="The Red Rover internal Id of Organization (numeric)")
    start_time: Optional[datetime] = Field(None, alias="startTime", description="The first date of the Absence")
    end_time: Optional[datetime] = Field(None, alias="endTime", description="The last date of the Absence")
    number_of_days: Optional[StrictInt] = Field(None, alias="numberOfDays", description="How many days the Absence spans")
    is_closed: Optional[StrictBool] = Field(None, alias="isClosed", description="If the Absence is closed")
    is_deleted: Optional[StrictBool] = Field(None, alias="isDeleted", description="If the Absence is deleted")
    approval_status: Optional[StrictStr] = Field(None, alias="approvalStatus", description="The approval status of the Absence")
    notes_to_approver: Optional[StrictStr] = Field(None, alias="notesToApprover", description="Any notes that are meant to go to the person who will approve this Absence")
    admin_only_notes: Optional[StrictStr] = Field(None, alias="adminOnlyNotes", description="Any notes that are entered by an admin for this Absence")
    total_duration: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="totalDuration", description="The total duration of this absence (minutes)")
    total_day_portion: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="totalDayPortion", description="The total duration of this absence (days)")
    employee: Optional[OrgUserEmployeeResponse] = None
    absence_details: Optional[conlist(AbsenceDetailResponse)] = Field(None, alias="absenceDetails", description="The details of the Absence")
    admin_edit_url: Optional[StrictStr] = Field(None, alias="adminEditUrl", description="The Url that the Admin can edit the Absence")
    employee_edit_url: Optional[StrictStr] = Field(None, alias="employeeEditUrl", description="The Url that the Employee can edit the Absence")
    vacancies: Optional[conlist(VacancyResponse)] = Field(None, description="The Vacancies associated with this Absence")
    __properties = ["id", "externalId", "orgId", "startTime", "endTime", "numberOfDays", "isClosed", "isDeleted", "approvalStatus", "notesToApprover", "adminOnlyNotes", "totalDuration", "totalDayPortion", "employee", "absenceDetails", "adminEditUrl", "employeeEditUrl", "vacancies"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AbsenceResponse:
        """Create an instance of AbsenceResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "admin_edit_url",
                            "employee_edit_url",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of employee
        if self.employee:
            _dict['employee'] = self.employee.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in absence_details (list)
        _items = []
        if self.absence_details:
            for _item in self.absence_details:
                if _item:
                    _items.append(_item.to_dict())
            _dict['absenceDetails'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in vacancies (list)
        _items = []
        if self.vacancies:
            for _item in self.vacancies:
                if _item:
                    _items.append(_item.to_dict())
            _dict['vacancies'] = _items
        # set to None if external_id (nullable) is None
        # and __fields_set__ contains the field
        if self.external_id is None and "external_id" in self.__fields_set__:
            _dict['externalId'] = None

        # set to None if approval_status (nullable) is None
        # and __fields_set__ contains the field
        if self.approval_status is None and "approval_status" in self.__fields_set__:
            _dict['approvalStatus'] = None

        # set to None if notes_to_approver (nullable) is None
        # and __fields_set__ contains the field
        if self.notes_to_approver is None and "notes_to_approver" in self.__fields_set__:
            _dict['notesToApprover'] = None

        # set to None if admin_only_notes (nullable) is None
        # and __fields_set__ contains the field
        if self.admin_only_notes is None and "admin_only_notes" in self.__fields_set__:
            _dict['adminOnlyNotes'] = None

        # set to None if absence_details (nullable) is None
        # and __fields_set__ contains the field
        if self.absence_details is None and "absence_details" in self.__fields_set__:
            _dict['absenceDetails'] = None

        # set to None if admin_edit_url (nullable) is None
        # and __fields_set__ contains the field
        if self.admin_edit_url is None and "admin_edit_url" in self.__fields_set__:
            _dict['adminEditUrl'] = None

        # set to None if employee_edit_url (nullable) is None
        # and __fields_set__ contains the field
        if self.employee_edit_url is None and "employee_edit_url" in self.__fields_set__:
            _dict['employeeEditUrl'] = None

        # set to None if vacancies (nullable) is None
        # and __fields_set__ contains the field
        if self.vacancies is None and "vacancies" in self.__fields_set__:
            _dict['vacancies'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AbsenceResponse:
        """Create an instance of AbsenceResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AbsenceResponse.parse_obj(obj)

        _obj = AbsenceResponse.parse_obj({
            "id": obj.get("id"),
            "external_id": obj.get("externalId"),
            "org_id": obj.get("orgId"),
            "start_time": obj.get("startTime"),
            "end_time": obj.get("endTime"),
            "number_of_days": obj.get("numberOfDays"),
            "is_closed": obj.get("isClosed"),
            "is_deleted": obj.get("isDeleted"),
            "approval_status": obj.get("approvalStatus"),
            "notes_to_approver": obj.get("notesToApprover"),
            "admin_only_notes": obj.get("adminOnlyNotes"),
            "total_duration": obj.get("totalDuration"),
            "total_day_portion": obj.get("totalDayPortion"),
            "employee": OrgUserEmployeeResponse.from_dict(obj.get("employee")) if obj.get("employee") is not None else None,
            "absence_details": [AbsenceDetailResponse.from_dict(_item) for _item in obj.get("absenceDetails")] if obj.get("absenceDetails") is not None else None,
            "admin_edit_url": obj.get("adminEditUrl"),
            "employee_edit_url": obj.get("employeeEditUrl"),
            "vacancies": [VacancyResponse.from_dict(_item) for _item in obj.get("vacancies")] if obj.get("vacancies") is not None else None
        })
        return _obj


