# coding: utf-8

"""
    Red Rover API

    Access Red Rover data via this REST API for Organizations that have granted you access.    # Authentication  The API is protected by HTTP Basic Authentication.   Each application that connects to the API has a unique username and password that it must supply with every request.    This value needs to be supplied as an HTTP Header: `Authorization=BASIC [hash]`. The value of [hash] is the string username:password base64 encoded.    Endpoints marked for Basic Auth can be used with the Basic Auth username and password that you have been assigned.    # API Information  ## Api Key  Each Red Rover organization that has authorized your application has a unique API Key for your application.  To retrieve the API Key, you can use the Organization endpoint (`api/v1/organization`) which returns an ApiKey uniquely used for each Organization.    You must supply this as an HTTP Header when accessing that organization: `apiKey=[apiKey]`. The domains that require this `ApiKey` header are labeled as 'Requires an ApiKey'.    ## Identifier  Where an `Identifier` can be specified in the route, you may either supply the Red Rover Id of the object (numeric) or the External Id (alpha-numeric). When specifying an External Id, you will need to prepend the External Id with the pike character`|` (e.g. `|ABC123`). Please note that this is only the case when the External Id is within the route. If the External Id is contained within the body of the request, do not append the pike character.    ## Transaction Id  Each request can be supplied with a `TransactionId` GUID which will be logged with the request. The `Transaction Id` can be supplied as an HTTP Header: `TransactionId=[transactionId]`. If no `Transaction Id` is supplied, one will be generated for you. Please use a distinct TransactionId for each request.

    The version of the OpenAPI document: v1
    Contact: dev@redroverk12.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from redrover_api.models.approval_status_enum import ApprovalStatusEnum
from redrover_api.models.fill_status_enum import FillStatusEnum
from redrover_api.models.int32_id_name_class import Int32IdNameClass
from redrover_api.models.simple_position_response import SimplePositionResponse
from redrover_api.models.vacancy_detail_response import VacancyDetailResponse

class VacancyResponse(BaseModel):
    """
    Vacancy  # noqa: E501
    """
    position: Optional[SimplePositionResponse] = None
    contract: Optional[Int32IdNameClass] = None
    approval_status: Optional[ApprovalStatusEnum] = Field(None, alias="approvalStatus")
    is_long_term: Optional[StrictBool] = Field(None, alias="isLongTerm", description="If the Vacancy is long term")
    notes_to_replacement: Optional[StrictStr] = Field(None, alias="notesToReplacement", description="Notes to the Substitute")
    admin_only_notes: Optional[StrictStr] = Field(None, alias="adminOnlyNotes", description="Notes for only Admins")
    administrator_comments: Optional[StrictStr] = Field(None, alias="administratorComments", description="Administrator comments")
    allow_sub_to_accept_part: Optional[StrictBool] = Field(None, alias="allowSubToAcceptPart", description="If the Vacancy can be accepted in parts")
    details: Optional[conlist(VacancyDetailResponse)] = Field(None, description="The Vacancy's Details")
    hold_for_manual_fill_until_utc: Optional[datetime] = Field(None, alias="holdForManualFillUntilUtc", description="When the Vacancy is held for manual fill")
    hold_for_auto_assign_until_utc: Optional[datetime] = Field(None, alias="holdForAutoAssignUntilUtc", description="When the Vacancy is held for auto assign")
    fill_status: Optional[FillStatusEnum] = Field(None, alias="fillStatus")
    absence_id: Optional[StrictInt] = Field(None, alias="absenceId", description="The Vacancy's AbsenceId if it is correlated to one")
    admin_edit_url: Optional[StrictStr] = Field(None, alias="adminEditUrl", description="The Url that the Admin can edit the Vacancy or Absence that it is associated with")
    id: Optional[StrictInt] = None
    external_id: Optional[StrictStr] = Field(None, alias="externalId")
    __properties = ["position", "contract", "approvalStatus", "isLongTerm", "notesToReplacement", "adminOnlyNotes", "administratorComments", "allowSubToAcceptPart", "details", "holdForManualFillUntilUtc", "holdForAutoAssignUntilUtc", "fillStatus", "absenceId", "adminEditUrl", "id", "externalId"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> VacancyResponse:
        """Create an instance of VacancyResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "admin_edit_url",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of position
        if self.position:
            _dict['position'] = self.position.to_dict()
        # override the default output from pydantic by calling `to_dict()` of contract
        if self.contract:
            _dict['contract'] = self.contract.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in details (list)
        _items = []
        if self.details:
            for _item in self.details:
                if _item:
                    _items.append(_item.to_dict())
            _dict['details'] = _items
        # set to None if notes_to_replacement (nullable) is None
        # and __fields_set__ contains the field
        if self.notes_to_replacement is None and "notes_to_replacement" in self.__fields_set__:
            _dict['notesToReplacement'] = None

        # set to None if admin_only_notes (nullable) is None
        # and __fields_set__ contains the field
        if self.admin_only_notes is None and "admin_only_notes" in self.__fields_set__:
            _dict['adminOnlyNotes'] = None

        # set to None if administrator_comments (nullable) is None
        # and __fields_set__ contains the field
        if self.administrator_comments is None and "administrator_comments" in self.__fields_set__:
            _dict['administratorComments'] = None

        # set to None if allow_sub_to_accept_part (nullable) is None
        # and __fields_set__ contains the field
        if self.allow_sub_to_accept_part is None and "allow_sub_to_accept_part" in self.__fields_set__:
            _dict['allowSubToAcceptPart'] = None

        # set to None if details (nullable) is None
        # and __fields_set__ contains the field
        if self.details is None and "details" in self.__fields_set__:
            _dict['details'] = None

        # set to None if hold_for_manual_fill_until_utc (nullable) is None
        # and __fields_set__ contains the field
        if self.hold_for_manual_fill_until_utc is None and "hold_for_manual_fill_until_utc" in self.__fields_set__:
            _dict['holdForManualFillUntilUtc'] = None

        # set to None if hold_for_auto_assign_until_utc (nullable) is None
        # and __fields_set__ contains the field
        if self.hold_for_auto_assign_until_utc is None and "hold_for_auto_assign_until_utc" in self.__fields_set__:
            _dict['holdForAutoAssignUntilUtc'] = None

        # set to None if absence_id (nullable) is None
        # and __fields_set__ contains the field
        if self.absence_id is None and "absence_id" in self.__fields_set__:
            _dict['absenceId'] = None

        # set to None if admin_edit_url (nullable) is None
        # and __fields_set__ contains the field
        if self.admin_edit_url is None and "admin_edit_url" in self.__fields_set__:
            _dict['adminEditUrl'] = None

        # set to None if external_id (nullable) is None
        # and __fields_set__ contains the field
        if self.external_id is None and "external_id" in self.__fields_set__:
            _dict['externalId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> VacancyResponse:
        """Create an instance of VacancyResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return VacancyResponse.parse_obj(obj)

        _obj = VacancyResponse.parse_obj({
            "position": SimplePositionResponse.from_dict(obj.get("position")) if obj.get("position") is not None else None,
            "contract": Int32IdNameClass.from_dict(obj.get("contract")) if obj.get("contract") is not None else None,
            "approval_status": obj.get("approvalStatus"),
            "is_long_term": obj.get("isLongTerm"),
            "notes_to_replacement": obj.get("notesToReplacement"),
            "admin_only_notes": obj.get("adminOnlyNotes"),
            "administrator_comments": obj.get("administratorComments"),
            "allow_sub_to_accept_part": obj.get("allowSubToAcceptPart"),
            "details": [VacancyDetailResponse.from_dict(_item) for _item in obj.get("details")] if obj.get("details") is not None else None,
            "hold_for_manual_fill_until_utc": obj.get("holdForManualFillUntilUtc"),
            "hold_for_auto_assign_until_utc": obj.get("holdForAutoAssignUntilUtc"),
            "fill_status": obj.get("fillStatus"),
            "absence_id": obj.get("absenceId"),
            "admin_edit_url": obj.get("adminEditUrl"),
            "id": obj.get("id"),
            "external_id": obj.get("externalId")
        })
        return _obj


