# coding: utf-8

"""
    Red Rover API

    Access Red Rover data via this REST API for Organizations that have granted you access.    # Authentication  The API is protected by HTTP Basic Authentication.   Each application that connects to the API has a unique username and password that it must supply with every request.    This value needs to be supplied as an HTTP Header: `Authorization=BASIC [hash]`. The value of [hash] is the string username:password base64 encoded.    Endpoints marked for Basic Auth can be used with the Basic Auth username and password that you have been assigned.    # API Information  ## Api Key  Each Red Rover organization that has authorized your application has a unique API Key for your application.  To retrieve the API Key, you can use the Organization endpoint (`api/v1/organization`) which returns an ApiKey uniquely used for each Organization.    You must supply this as an HTTP Header when accessing that organization: `apiKey=[apiKey]`. The domains that require this `ApiKey` header are labeled as 'Requires an ApiKey'.    ## Identifier  Where an `Identifier` can be specified in the route, you may either supply the Red Rover Id of the object (numeric) or the External Id (alpha-numeric). When specifying an External Id, you will need to prepend the External Id with the pike character`|` (e.g. `|ABC123`). Please note that this is only the case when the External Id is within the route. If the External Id is contained within the body of the request, do not append the pike character.    ## Transaction Id  Each request can be supplied with a `TransactionId` GUID which will be logged with the request. The `Transaction Id` can be supplied as an HTTP Header: `TransactionId=[transactionId]`. If no `Transaction Id` is supplied, one will be generated for you. Please use a distinct TransactionId for each request.

    The version of the OpenAPI document: v1
    Contact: dev@redroverk12.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, constr

class WebhookResponse(BaseModel):
    """
    WebhookResponse
    """
    webhook_uri: Optional[StrictStr] = Field(None, alias="webhookUri", description="The absolute uri that data will be posted to")
    id: Optional[StrictStr] = Field(None, description="The Id of the Webhook (Guid)")
    version: Optional[StrictStr] = Field(None, description="The version of the webhook")
    created: Optional[datetime] = Field(None, description="When the webhook was created")
    updated: Optional[datetime] = Field(None, description="When the webhook was last updated")
    topic: Optional[StrictStr] = Field(None, description="Webhook topics are structure like such `DOMAIN/ACTION`.   Supported domains are `absence`, `vacancy`, `substitute_assignment`.  Supported actions are `create`, `update`, `delete`.")
    basic_auth_username: Optional[constr(strict=True, max_length=100)] = Field(None, alias="basicAuthUsername", description="The Basic Auth username for the Basic Auth header that will be included in the Webhook payload")
    basic_auth_password: Optional[constr(strict=True, max_length=100)] = Field(None, alias="basicAuthPassword", description="The Basic Auth password for the Basic Auth header that will be included in the Webhook payload")
    is_active: Optional[StrictBool] = Field(None, alias="isActive", description="If the Webhook is active")
    __properties = ["webhookUri", "id", "version", "created", "updated", "topic", "basicAuthUsername", "basicAuthPassword", "isActive"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WebhookResponse:
        """Create an instance of WebhookResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if webhook_uri (nullable) is None
        # and __fields_set__ contains the field
        if self.webhook_uri is None and "webhook_uri" in self.__fields_set__:
            _dict['webhookUri'] = None

        # set to None if version (nullable) is None
        # and __fields_set__ contains the field
        if self.version is None and "version" in self.__fields_set__:
            _dict['version'] = None

        # set to None if topic (nullable) is None
        # and __fields_set__ contains the field
        if self.topic is None and "topic" in self.__fields_set__:
            _dict['topic'] = None

        # set to None if basic_auth_username (nullable) is None
        # and __fields_set__ contains the field
        if self.basic_auth_username is None and "basic_auth_username" in self.__fields_set__:
            _dict['basicAuthUsername'] = None

        # set to None if basic_auth_password (nullable) is None
        # and __fields_set__ contains the field
        if self.basic_auth_password is None and "basic_auth_password" in self.__fields_set__:
            _dict['basicAuthPassword'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WebhookResponse:
        """Create an instance of WebhookResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return WebhookResponse.parse_obj(obj)

        _obj = WebhookResponse.parse_obj({
            "webhook_uri": obj.get("webhookUri"),
            "id": obj.get("id"),
            "version": obj.get("version"),
            "created": obj.get("created"),
            "updated": obj.get("updated"),
            "topic": obj.get("topic"),
            "basic_auth_username": obj.get("basicAuthUsername"),
            "basic_auth_password": obj.get("basicAuthPassword"),
            "is_active": obj.get("isActive")
        })
        return _obj


